@rem Licensed Materials-Property of IBM
@rem (C)Copyright IBM Corp 2009
@rem All rights reserved
@rem US Government Users Restricted Rights
@rem Use, duplication, or disclosure restricted
@rem by GSA ADP Schedule Contract with IBM Corp
@echo OFF
goto :MAIN

:ClearErrorLevel
    
    @rem Input   : reqires the following environment variables
    @rem Output  : sets the following environment variables 
    @rem Process : Following tasks are performed during pre-migration 
    @rem Clear ERRORLEVEL so || and && operators work correctly...
    
    ( dir %COMPSPEC% 2>&1 ) >NUL

@rem End ClearErrorLevel
goto :EOF

:initEnv

    @rem Input   : reqires the following environment variables
    @rem Output  : sets the following environment variables 
    @rem Process : Initialize the environment variables

    set CLEANUP=1
    set ERROR=
    set RES_FILE=
    set VBS_FILE=
    set OPTION_N=
    set INST_PROP_FILE=

    set DB2PATH=
    set DB2NLOC=0
    set DB2OLOC=0
    set DB2NVER=
    set DB2OVER=
    set DB2_DBNAME=
    set DB2_INSTANCE=
    set CHGLOG_DEFINED=
    set TKLMDBMIGR_LOG=
    set DB2V97_MINOR_VER=0
    set DB2V91_MINOR_VER=0


@rem End initEnv
goto :EOF

:ParseCmdLine

    @rem Input   : reqires the following environment variables
    @rem           1) %*
    @rem Output  : sets the following environment variables 
    @rem           1) ERROR
    @rem Process : Following tasks are performed during pre-migration 
    set TKLM_HOME=%~s1
    set DB2OLOC=%~s2
    set DB2NLOC=%~s3
    set DB2_INSTANCE=%4
    set DB2_USERNAME=%4
    set DB2_DBNAME=%5
    set DB2_PWD=%6
    set DB2_PORT=%7
    set ACTION=%8
    set SVCE=DB2_%DB2_INSTANCE%
    @rem export SVCE_NAME=DB2_${DB2_INSTANCE}
    echo :ParseCmdLine

@rem End ParseCmdLine
goto :EOF

:USAGE
    exit /B %ERROR%
@rem End USAGE
goto :EOF


:prepare_db2_start_dbm

    set DB2INSTANCE=%DB2_INSTANCE%

    @rem start the database manager
    @rem ERRORLEVEL 4 is the SQL state error if the db manager is already started
    @rem we will get the sqlsate error, its safe to ignore this error here

    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv start database manager>>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv start database manager>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    IF (%RC%) GTR  (4) (
       SET ERROR=20
    )

goto :EOF

:prepare_db2_stop_dbm

    set DB2INSTANCE=%DB2_INSTANCE%

    @rem  terminate the current connection
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=10
        goto :EOF
    )

    @rem  terminate all applications connected to the database
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv force application all>>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv force application all>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=11
        goto :EOF
    )

    @rem stop the database manager
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2stop force >>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2stop force >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=12
        goto :EOF
    )

goto :EOF

:prepare_db2_restart_dbm

    call :prepare_db2_stop_dbm

    call :prepare_db2_start_dbm

goto :EOF

:pre_migration

    @rem Input   : reqires the following environment variables
    @rem           1) DB2OLOC
    @rem           2) DB2_INSTANCE
    @rem           3) DB2_DBNAME
    @rem           4) TKLM_HOME
    @rem           which is picked up from the properties file
    @rem Output  : sets the following environment variables 
    @rem           1) ERRORLEVEL 
    @rem           2) ERROR
    @rem Process : Following tasks are performed during pre-migration 
    @rem           2) start the database manager for DB2_INSTANCE
    @rem           3) connect to the DB2 database DB2_DBNAME
    @rem           4) update the DBM CFG to DIAGLEVEL 4
    @rem           5) terminate all connections to the DB2 database DB2_DBNAME

    set DB2INSTANCE=%DB2_INSTANCE%

    echo :pre_migration >> %TKLMDBMIGR_LOG%
    if NOT ("%ACTION%")==("preMigrate") (
       goto :EOF
    )



    call :prepare_db2_start_dbm

    @rem list database directory
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv list db directory >> %TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv list db directory >> %TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=30
        goto :EOF
    )

    @rem  connect to the database
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv connect to %DB2_DBNAME% user %DB2_USERNAME% using ****** >>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv connect to %DB2_DBNAME% user %DB2_USERNAME% using %DB2_PWD%>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=31
        goto :EOF
    )

    @rem update the DIAGLEVEL level
    echo "%DB2OLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING DIAGLEVEL 4 >>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING DIAGLEVEL 4 >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=32
        goto :EOF
    )

    @rem update the LOGSECOND to -1
    echo "%DB2OLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DB CFG FOR %DB2_DBNAME% USING LOGSECOND -1 >>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DB CFG FOR %DB2_DBNAME% USING LOGSECOND -1 >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=34
        goto :EOF
    )

    @rem  terminate the current connection
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=33
        goto :EOF
    )
    call :deactivate_db
    call :prepare_db2_stop_dbm

@rem End pre_migration
goto :EOF

:migrate_db

    @rem Input   : reqires the following environment variables
    @rem           1) DB2V8PATH
    @rem           2) DB2NLOC
    @rem           3) DB2_INSTANCE
    @rem           4) DB2_DBNAME
    @rem           5) DB2N
    @rem Output  : sets the following environment variables 
    @rem           1) ERROR
    @rem Process : Following tasks are performed during migration 
    @rem           1) migrate the DB2 instance from DB2 9 directory
    @rem           2) start the DB2 9.1 database manager 
    @rem           3) migrate the DB2 database 

    echo ":migrate_db" >> %TKLMDBMIGR_LOG%

    if NOT ("%ACTION%")==("migrateDb") (
       goto :EOF
    )
    set DB2INSTANCE=%DB2_INSTANCE%
    @rem update the AGENT_STACK_SZ level
    echo "%DB2NLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING AGENT_STACK_SZ 128>>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING AGENT_STACK_SZ 128 >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=32
        goto :EOF
    )

    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2stop force >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2stop force >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
   
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2start >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2start >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=105
        goto :EOF
    )

    @rem migrate the database
    
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv migrate database %DB2_DBNAME% >> %TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv migrate database %DB2_DBNAME% >> %TKLMDBMIGR_LOG%
    
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) GTR (2) ( 
                set ERROR=40
                goto :EOF
    )
     
 @rem update the AGENT_STACK_SZ to 16
    echo "%DB2NLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING AGENT_STACK_SZ 16 >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%".\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING AGENT_STACK_SZ 16 >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=32
        goto :EOF
    )
    @rem stop the database manager
    @rem echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv stop database manager>>%TKLMDBMIGR_LOG%
    @rem call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv stop database manager>>%TKLMDBMIGR_LOG%
    @rem if (%ERRORLEVEL%) NEQ (0) ( 
    @rem     set ERROR=18
    @rem     goto :EOF
    @rem )


@rem migrate_db
goto :EOF

:deactivate_db
    echo ":deactivate_db" >> %TKLMDBMIGR_LOG%
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2 deactivate db %DB2_DBNAME% >>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2  deactivate db %DB2_DBNAME% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) GTR (2) (
           set ERROR=40
           goto :EOF
    )
    @rem deactivate_db
goto :EOF

:ckmigrate_db
    echo ":ckmigrate_db" >> %TKLMDBMIGR_LOG%
    set OPATH=%PATH%
    set PATH=%DBNLOC%/BIN;%DBNLOC%/SQLLIB/function;%PATH%
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2ckupgrade %DB2_DBNAME%  -l %TKLM_HOME%\db2ckiupgrade.log >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2ckupgrade %DB2_DBNAME%  -l %TKLM_HOME%\db2ckiupgrade.log >>%TKLMDBMIGR_LOG%
    SET PATH=%OPATH%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=50
        goto :EOF
    )
    @rem ckmigrate_db
goto :EOF

:drop_instance
    echo ":drop_instance" >> %TKLMDBMIGR_LOG%
    if NOT ("%ACTION%")==("dropInstance") (
       goto :EOF
    )
    echo "%DB2OLOC%"\BIN\db2cmd -c -w -i db2idrop %DB2_INSTANCE% >>%TKLMDBMIGR_LOG%
    call "%DB2OLOC%"\BIN\db2cmd -c -w -i db2idrop %DB2_INSTANCE% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=60
        goto :EOF
    )
    @rem drop_instance
goto :EOF

:recreate_instance
    echo :recreate_instance >> %TKLMDBMIGR_LOG%
    if NOT ("%ACTION%")==("createInstance") (
       goto :EOF
    )
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2icrt %DB2_INSTANCE% -s wse -u:%DB2_USERNAME%, ****** >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2icrt %DB2_INSTANCE% -s wse -u:%DB2_USERNAME%,%DB2_PWD% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=70
        goto :EOF
    )
    @rem recreate the instance
goto :EOF

:catalog_db
    if NOT ("%ACTION%")==("catalogDb") (
       goto :EOF
    )
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 catalog DB %DB2_DBNAME% >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 catalog DB %DB2_DBNAME% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=80
        goto :EOF
    )
    @rem catalog_db
goto :EOF

:post_migration

    @rem Input   : reqires the following environment variables
    @rem           1) DB2NLOC
    @rem           2) DB2_INSTANCE
    @rem           3) DB2_DBNAME
    @rem Output  : sets the following environment variables 
    @rem           1) ERROR
    @rem Process : Following tasks are performed during pre-migration 
    @rem           1) rebind the DB2 packages
    @rem           2) start the database manager
    @rem           3) reset the DIAGLEVEL
    @rem           4) update the global TDS ldapd.properties file and
    @rem              instance specific ldapd.properties file

    echo.
    echo :post_migration >> %TKLMDBMIGR_LOG%
    if NOT ("%ACTION%")==("setServerConfig") (
       goto :EOF
    )

    set DB2INSTANCE=%DB2_INSTANCE%
    set RBIND_LOGFILE=%DB2_DBNAME%.log

    db2set DB2COMM=tcpip
    echo ""%DB2NLOC%"\BIN\db2cmd -c -i -w db2set DB2COMM=tcpip" >> %TKLMDBMIGR_LOG%
    "%DB2NLOC%"\BIN\db2cmd -c -i -w db2set DB2COMM=tcpip" >> %TKLMDBMIGR_LOG%
    echo "%DB2NLOC%"\BIN\db2cmd -c -i -w db2 update dbm cfg USING SVCENAME %SVCE% >>%TKLMDBMIGR_LOG%
    "%DB2NLOC%"\BIN\db2cmd -c -i -w db2 update dbm cfg USING SVCENAME %SVCE% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        SET ERROR=100
        goto :EOF
    )

    echo "%DB2NLOC%"\BIN\db2cmd -c -i -w db2 update dbm cfg USING HEATH_MON OFF >>%TKLMDBMIGR_LOG%
    "%DB2NLOC%"\BIN\db2cmd -c -i -w db2 update dbm cfg USING HEALTH_MON OFF >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        SET ERROR=101
        goto :EOF
    )

    @rem update the LOGSECOND to  25
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv UPDATE DB CFG FOR %DB2_DBNAME% USING LOGSECOND  25 >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv UPDATE DB CFG FOR %DB2_DBNAME% USING LOGSECOND 25 >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) (
        set ERROR=34
        goto :EOF
    )
    call :prepare_db2_restart_dbm 
    @rem rebind the DB2 database packages
    echo "%DB2NLOC%"\BIN\db2rbind %DB2_DBNAME% -l %RBIND_LOGFILE% >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2rbind %DB2_DBNAME% -l %RBIND_LOGFILE% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=100
        goto :EOF
    )

    @rem call :prepare_db2_start_dbm

    @rem start the database manager
    @rem ERRORLEVEL 4 is the SQL state error if the db manager is already started
    @rem we will get the sqlsate error, its safe to ignore this error here

    @rem update the DIAGLEVEL
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING DIAGLEVEL 3 >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv UPDATE DBM CFG USING DIAGLEVEL 3 >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=102
        goto :EOF
    )

    @rem list database directory
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv list db directory>>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv list db directory>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=103
        goto :EOF
    )

    @rem  connect to the database
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv connect to %DB2_DBNAME% >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv connect to %DB2_DBNAME% >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=104
        goto :EOF
    )

    @rem  terminate the current connection
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2 -tv terminate>>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=105
        goto :EOF
    )
    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2stop force >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2stop force >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=105
        goto :EOF
    )

    echo "%DB2NLOC%"\BIN\db2cmd -c -w -i db2start >>%TKLMDBMIGR_LOG%
    call "%DB2NLOC%"\BIN\db2cmd -c -w -i db2start >>%TKLMDBMIGR_LOG%
    SET RC=%ERRORLEVEL%
    ECHO RC=%RC% >> %TKLMDBMIGR_LOG%
    if (%RC%) NEQ (0) ( 
        set ERROR=105
        goto :EOF
    )

@rem End post_migration
goto :EOF


:MAIN

    @rem Input   : reqires the following environment variables
    @rem Output  : sets the following environment variables 
    @rem Process : Following tasks are performed during post-migration 
    @rem Get the absolute path to the file

    call :initEnv

    call :ParseCmdLine %*
    if defined ERROR goto :EOF
    set TKLMDBMIGR_LOG="%TKLM_HOME%\migration\migrate_tklmdbmigr.log"


    @rem get the DB2 instance name and DB2 database name from the TDS 6.2
    @rem instance configuration file

    if NOT DEFINED TKLM_HOME (
        exit /B 1
    )
     
   
    if NOT DEFINED DB2OLOC (
        exit /B 2
    )

    if NOT DEFINED DB2NLOC (
        exit /B 3
    )

    if NOT defined DB2_INSTANCE ( 
        exit /B 4
    )

    if NOT defined DB2_DBNAME (
        exit /B 5 
    )
     
    if NOT defined DB2_USERNAME (
        exit /B 6 
    )

    if NOT defined DB2_PWD (
        echo Return 7
        exit /B 7 
    )

    if NOT defined DB2_PORT (
        echo Return 8
        exit /B 8 
    )

    @rem Perform the below comparasion only if the path variables are defined
    @rem or else if might result in an syntax error
    
    @rem Perform the migration steps if required
    @rem Perform the pre-migrations steps always

    call :pre_migration
    if defined ERROR (
        echo Return %ERROR% 
	exit /B %ERROR%
    )
    set PWD=%~dp0
    cd %TKLM_HOME%\migration

@rem    if %NEED_DB2_MIG% == 1 (
@rem
@rem	    @rem change the directory to IDS_LDAP_HOME\var so that the temporary DB2 files
@rem	    @rem will be created in the IDS_LDAP_HOME\var directory
@rem
@rem	    cd %TKLM_HOME%\migration
@rem	    @rem if -N option is provided then perform the migration and post-migration tasks
@rem	    if defined DB2N (
@rem		if defined DB2NLOC ( 
@rem		    call :migration
@rem		    if defined ERROR (
@rem		      cd %PWD%
@rem		      exit /B %ERROR%
@rem		    )
@rem		    call :post_migration
@rem		    if defined ERROR (
@rem		       cd %PWD%
@rem		       exit /B %ERROR%
@rem		    )
@rem		) else ( 
@rem		    cd %PWD%
@rem		    exit /B %ERROR%
@rem		)
@rem	    )
@rem    )


    @rem lets get back to our original directory

@rem call :get_DB2_Version
@rem call :deactivate_db
@rem call :ckmigrate_db
@rem   if defined ERROR (
@rem	exit /B %ERROR%
@rem    )
@rem call :prepare_db2_stop_dbm
@rem    if defined ERROR (
@rem       exit /B %ERROR%
@rem    )

call :drop_instance
if defined ERROR (
        echo Return %ERROR% 
        exit /B %ERROR%
)
call :recreate_instance
if defined ERROR (
        echo Return  %ERROR%
        exit /B %ERROR%
)
call :catalog_db                                                                       
    if defined ERROR (
        echo Return %ERROR% 
	exit /B %ERROR%
    )
call :migrate_db
    if defined ERROR (
        echo Return %ERROR% 
	exit /B %ERROR%
    )
call :post_migration
    if defined ERROR (
        echo Return %ERROR% 
	exit /B %ERROR%
    )
    cd %PWD% > NUL
    echo Return=0
    exit /B 0

@rem End MAIN
:end
